@@ -1,11 +1,12 @@
 # HMOMENT
 # This function compute the hmoment based on Eisenberg, D., Weiss, R. M., & Terwilliger, T. C. (1984). 
 # The hydrophobic moment detects periodicity in protein hydrophobicity. 
-# Proceedings of the National Academy of Sciences of the United States of America, 81(1), 140–4.
+# Proceedings of the National Academy of Sciences of the United States of America, 81(1), 140-4.
 # This function was written by an anonymous reviewer of the RJournal
 
 hmoment<-function(seq,angle=100,window=11){
   # Loading hydrophobicity scale
+  seq<-gsub("[\r\n]","",seq)
   data(H,envir = environment())
   H<-H
   h<-H[["Eisenberg"]]
